{{#if (isClass)~}}
    {{>classdesc~}}
    {{>augments~}}
    {{else~}}
    {{>description~}}
    {{>params~}}
    {{>properties~}}
    {{>deprecated~}}
    {{>augments~}}
    {{>memberof~}}
    {{>default~}}
    {{>throws~}}
    {{>returns~}}
    {{>access~}}
    {{>enum~}}
    {{>readOnly~}}
    {{>since~}}
    {{>version~}}
    {{>authors~}}
    {{>license~}}
    {{>copyright~}}
    {{>examples~}}
{{/if~}}