{{#if (equal kind "class")~}}
    {{#if isConstructor}}new {{else}}class: {{/if~}}
{{/if~}}
{{#if (equal kind "constant")~}}const: {{/if~}}
{{#if (equal kind "event")~}}event: {{/if~}}
{{#if isEnum}}enum: {{/if~}}
{{#if (equal kind "typedef")~}}type: {{/if}}