'use strict';

exports.all = exports.and = require('./src/all');
exports.any = exports.or = require('./src/any');
exports.array = exports.arr = require('./src/array');
exports.arrayLike = exports.arrLike = require('./src/arrayLike');
exports.arrayOf = exports.arrOf = require('./src/arrayOf');
exports.blank = require('./src/blank');
exports.boolean = exports.bool = require('./src/boolean');
exports.date = require('./src/date');
exports.defined = require('./src/defined');
exports.divisible = exports.divisibleBy = exports.divBy = require('./src/divisible');
exports.divisibleWithRemainder = exports.divisibleByWithRemainder = exports.divByWithRemainder = require('./src/divisibleWithRemainder');
exports.empty = require('./src/empty');
exports.endsWith = require('./src/endsWith');
exports.equal = exports.equalTo = exports.eq = require('./src/equal');
exports.false = require('./src/false');
exports.falsy = exports.falsey = require('./src/falsy');
exports.finite = require('./src/finite');
exports.function = exports.fn = exports.func = require('./src/function');
exports.greaterThan = exports.greater = exports.gt = require('./src/greaterThan');
exports.greaterThanOrEqual = exports.greaterOrEqual = exports.greaterEq = exports.gtEq = require('./src/greaterThanOrEqual');
exports.hasOwnProperty = exports.hasOwn = require('./src/hasOwnProperty');
exports.hasProperty = exports.has = require('./src/hasProperty');
exports.in = require('./src/in');
exports.instanceOf = exports.instance = require('./src/instanceOf');
exports.integer = exports.int = require('./src/integer');
exports.lessThan = exports.less = exports.lt = require('./src/lessThan');
exports.lessThanOrEqual = exports.lessOrEqual = exports.lessEq = exports.ltEq = require('./src/lessThanOrEqual');
exports.matches = exports.match = require('./src/matches');
exports.notANumber = exports.nan = exports.NaN = require('./src/nan');
exports.negative = require('./src/negative');
exports.not = exports.negate = require('./src/not');
exports.notBlank = require('./src/notBlank');
exports.notEmpty = require('./src/notEmpty');
exports.null = require('./src/null');
exports.number = exports.num = require('./src/number');
exports.object = exports.obj = require('./src/object');
exports.objectOf = exports.objOf = require('./src/objectOf');
exports.oneOf = require('./src/oneOf');
exports.plainObject = require('./src/plainObject');
exports.positive = require('./src/positive');
exports.primitive = require('./src/primitive');
exports.property = exports.prop = require('./src/property');
exports.regexp = exports.regExp = require('./src/regexp');
exports.startsWith = require('./src/startsWith');
exports.strictEqual = exports.strictEqualTo = require('./src/strictEqual');
exports.string = exports.str = require('./src/string');
exports.structure = require('./src/structure');
exports.true = require('./src/true');
exports.truthy = require('./src/truthy');
exports.undefined = require('./src/undefined');
exports.undefinedOr = require('./src/undefinedOr');
